@@ -287,96 +287,3 @@ GeomYMarginPoint <-
 
           draw_key = ggplot2:::draw_key_point
   )
-
-
-## utils
-
-# copied from 'ggplo2' 3.1.0 geom-point.r as this function is not exported.
-translate_shape_string <- function(shape_string) {
-  # strings of length 0 or 1 are interpreted as symbols by grid
-  if (nchar(shape_string[1]) <= 1) {
-    return(shape_string)
-  }
-
-  pch_table <- c(
-    "square open"           = 0,
-    "circle open"           = 1,
-    "triangle open"         = 2,
-    "plus"                  = 3,
-    "cross"                 = 4,
-    "diamond open"          = 5,
-    "triangle down open"    = 6,
-    "square cross"          = 7,
-    "asterisk"              = 8,
-    "diamond plus"          = 9,
-    "circle plus"           = 10,
-    "star"                  = 11,
-    "square plus"           = 12,
-    "circle cross"          = 13,
-    "square triangle"       = 14,
-    "triangle square"       = 14,
-    "square"                = 15,
-    "circle small"          = 16,
-    "triangle"              = 17,
-    "diamond"               = 18,
-    "circle"                = 19,
-    "bullet"                = 20,
-    "circle filled"         = 21,
-    "square filled"         = 22,
-    "diamond filled"        = 23,
-    "triangle filled"       = 24,
-    "triangle down filled"  = 25
-  )
-
-  shape_match <- charmatch(shape_string, names(pch_table))
-
-  invalid_strings <- is.na(shape_match)
-  nonunique_strings <- shape_match == 0
-
-  if (any(invalid_strings)) {
-    bad_string <- unique(shape_string[invalid_strings])
-    n_bad <- length(bad_string)
-
-    collapsed_names <- sprintf("\n* '%s'", bad_string[1:min(5, n_bad)])
-
-    more_problems <- if (n_bad > 5) {
-      sprintf("\n* ... and %d more problem%s", n_bad - 5, ifelse(n_bad > 6, "s", ""))
-    }
-
-    stop(
-      "Can't find shape name:",
-      collapsed_names,
-      more_problems,
-      call. = FALSE
-    )
-  }
-
-  if (any(nonunique_strings)) {
-    bad_string <- unique(shape_string[nonunique_strings])
-    n_bad <- length(bad_string)
-
-    n_matches <- vapply(
-      bad_string[1:min(5, n_bad)],
-      function(shape_string) sum(grepl(paste0("^", shape_string), names(pch_table))),
-      integer(1)
-    )
-
-    collapsed_names <- sprintf(
-      "\n* '%s' partially matches %d shape names",
-      bad_string[1:min(5, n_bad)], n_matches
-    )
-
-    more_problems <- if (n_bad > 5) {
-      sprintf("\n* ... and %d more problem%s", n_bad - 5, ifelse(n_bad > 6, "s", ""))
-    }
-
-    stop(
-      "Shape names must be unambiguous:",
-      collapsed_names,
-      more_problems,
-      call. = FALSE
-    )
-  }
-
-  unname(pch_table[shape_match])
-}
