@@ -1,4 +1,5 @@
-#' Label pairwise comparisons
+#' @title Label pairwise comparisons
+#' @include ggp2-margins.R utilities.R ggpp-legend-draw.R
 #'
 #' @description Add a plot layer with a text label and a segment connecting two
 #'   values along the \code{x} aesthetic. These are usually two levels of a
@@ -91,6 +92,9 @@
 #'   same layer will not be plotted. \code{check_overlap} takes place at draw
 #'   time and in the order of the data, thus its action depends of the size at
 #'   which the plot is drawn.
+#' @param size.unit How the `size` aesthetic is interpreted: as millimetres
+#'   (`"mm"`, default), points (`"pt"`), centimetres (`"cm"`), inches (`"in"`),
+#'   or picas (`"pc"`).
 #' @param ... other arguments passed on to \code{\link[ggplot2]{layer}}. There
 #'   are three types of arguments you can use here:
 #'
@@ -271,11 +275,12 @@ geom_text_pairwise <- function(mapping = NULL,
                                default.color = default.colour,
                                colour.target = "all",
                                color.target = colour.target,
-                               default.alpha = 1,
+                               default.alpha = NA,
                                alpha.target = "all",
                                segment.linewidth = 0.5,
                                arrow = NULL,
                                check_overlap = FALSE,
+                               size.unit = "mm",
                                na.rm = FALSE,
                                show.legend = NA,
                                inherit.aes = FALSE) {
@@ -316,6 +321,7 @@ geom_text_pairwise <- function(mapping = NULL,
       segment.linewidth = segment.linewidth,
       arrow = arrow,
       check_overlap = check_overlap,
+      size.unit = size.unit,
       na.rm = na.rm,
       ...
     )
@@ -337,7 +343,7 @@ GeomTextPairwise <-
                      angle = 0,
                      hjust = 0.5,
                      vjust = -0.5,
-                     alpha = 1,
+                     alpha = NA,
                      family = "",
                      fontface = 1,
                      lineheight = 1.2
@@ -347,9 +353,10 @@ GeomTextPairwise <-
                                          panel_params,
                                          coord, #panel_scales,
                                          parse = FALSE,
+                                         size.unit = "mm",
                                          default.colour = "black",
                                          colour.target = "all",
-                                         default.alpha = 1,
+                                         default.alpha = NA,
                                          alpha.target = "all",
                                          na.rm = FALSE,
                                          check_overlap = FALSE,
@@ -386,6 +393,8 @@ GeomTextPairwise <-
                                         a = "x", b = "y")
                      }
 
+                     size.unit <- resolve_text_unit(size.unit)
+
                      # loop needed as gpar is not vectorized
                      all.grobs <- grid::gList()
 
@@ -409,7 +418,7 @@ GeomTextPairwise <-
                            col = ifelse(any(colour.target %in% c("all", "text")),
                                         ggplot2::alpha(row$colour, text.alpha),
                                         ggplot2::alpha(default.colour, text.alpha)),
-                           fontsize = row$size * .pt,
+                           fontsize = row$size * size.unit,
                            fontfamily = row$family,
                            fontface = row$fontface,
                            lineheight = row$lineheight
@@ -444,5 +453,5 @@ GeomTextPairwise <-
 
                    },
 
-                   draw_key = draw_key_text
+                   draw_key = draw_key_text_s
   )
